==> v.2.7.tar.gz: rain/README.md <==
<div align="center">
<img src="/assets/icons/icon.png" width="150"/>
<h2>Rain</h2>
</div>

### Short Description:

<!-- Приложение для просмотра погоды в вашем городе -->

An application for viewing the weather in your city

### Description:

<!-- Данное приложение позволяет смотреть погоду в вашем городе.
Предоставлены следующие возможности:
- Просмотр погоды на данный момент
- Просмотр погоды по часам
- Просмотр погоды на неделю
- Просмотр подробных данных о погоде
- Локализация (ru/en/it/de/fr/tr/pt/es)
- Кэширование данных
- Выбор города самостоятельно
- Добавление карточек других городов
- Выбор между метрической системой мер и имперской
- Выбор между градусами Цельсия и Фаренгейта
- Выбор между форматом времени 12 и 24-часовым
Также мы постарались сделать дизайн максимально удобным и красивым. -->

This application allows you to view the weather in your city.
The following options are provided:

- View current weather
- View weather by hour
- View the weather for the week
- View detailed weather data
- Localization (ru/en/it/de/fr/tr/pt/es)
- Data caching
- Choose the city yourself
- Adding cards of other cities
- The choice between the metric system of measures and the imperial
- Choose between Celsius and Fahrenheit
- Choosing between 12-hour and 24-hour time formats

We also tried to make the design as convenient and beautiful as possible.

### Services used:

- The app receives weather data from [Open-Meteo](https://open-meteo.com/en/docs)
- Cities are searched using [Open-Meteo](https://open-meteo.com/en/docs/geocoding-api)

### Screenshots:

<img src="/readme/1.png" width="200"/> <img src="/readme/2.png" width="200"/> <img src="/readme/3.png" width="200"/> <img src="/readme/4.png" width="200"/>

### Download:

[![Play Store](https://img.shields.io/badge/Google_Play-414141?style=for-the-badge&logo=google-play&logoColor=white)](https://play.google.com/store/apps/details?id=com.yoshi.rain)
[![RuStore](https://img.shields.io/badge/RuStore-blue?style=for-the-badge&logo=vk&logoColor=white)](https://apps.rustore.ru/app/com.yoshi.rain)

Or get the latest APK from the [Releases Section](https://github.com/DarkMooNight/Rain/releases/latest). You can also find the app on IzzyOnDroid via a F-Droid client [here](https://apt.izzysoft.de/fdroid/index/apk/com.yoshi.rain).

==> v.2.8.tar.gz: rain/README.md <==
<div align="center">
<img src="/assets/icons/icon.png" width="150"/>
<h2>Rain</h2>
</div>

### Short Description:

<!-- Приложение для просмотра погоды в вашем городе -->

An application for viewing the weather in your city

### Description:

<!-- Данное приложение позволяет смотреть погоду в вашем городе.
Предоставлены следующие возможности:
- Просмотр погоды на данный момент
- Просмотр погоды по часам
- Просмотр погоды на неделю
- Просмотр подробных данных о погоде
- Локализация (ru/en/it/de/fr/tr/pt/es/sk/nl)
- Кэширование данных
- Выбор города самостоятельно
- Добавление карточек других городов
- Выбор между метрической системой мер и имперской
- Выбор между градусами Цельсия и Фаренгейта
- Выбор между форматом времени 12 и 24-часовым
Также мы постарались сделать дизайн максимально удобным и красивым. -->

This application allows you to view the weather in your city.
The following options are provided:

- View current weather
- View weather by hour
- View the weather for the week
- View detailed weather data
- Localization (ru/en/it/de/fr/tr/pt/es/sk/nl)
- Data caching
- Choose the city yourself
- Adding cards of other cities
- The choice between the metric system of measures and the imperial
- Choose between Celsius and Fahrenheit
- Choosing between 12-hour and 24-hour time formats

We also tried to make the design as convenient and beautiful as possible.

### Services used:

- The app receives weather data from [Open-Meteo](https://open-meteo.com/en/docs)
- Cities are searched using [Open-Meteo](https://open-meteo.com/en/docs/geocoding-api)

### Screenshots:

<img src="/readme/1.png" width="200"/> <img src="/readme/2.png" width="200"/> <img src="/readme/3.png" width="200"/> <img src="/readme/4.png" width="200"/>

### Download:

[![Play Store](https://img.shields.io/badge/Google_Play-414141?style=for-the-badge&logo=google-play&logoColor=white)](https://play.google.com/store/apps/details?id=com.yoshi.rain)
[![RuStore](https://img.shields.io/badge/RuStore-blue?style=for-the-badge&logo=vk&logoColor=white)](https://apps.rustore.ru/app/com.yoshi.rain)

Or get the latest APK from the [Releases Section](https://github.com/DarkMooNight/Rain/releases/latest). You can also find the app on IzzyOnDroid via a F-Droid client [here](https://apt.izzysoft.de/fdroid/index/apk/com.yoshi.rain).
